==> ui-react-1.0.84.tgz: package/esm/ClickListener/ClickListener.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["mouseEvent", "touchEvent", "contextMenu", "include", "includeParentQueries", "includeQueries", "ignoreNonExisting", "onClickInside", "onClickOutside", "children"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
import React from 'react';
import { is, element, Try, isEnvironment } from '@onesy/utils';
import { classNames, useOnesyTheme } from '@onesy/style-react';
import { matches } from '../utils';
const resolve = value => value.replace(/^on/, '').toLowerCase();
const ClickListener = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useOnesyTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.onesyClickListener?.props?.default), props_), [props_]);
  const {
      mouseEvent = 'onClick',
      touchEvent = 'onTouchEnd',
      contextMenu = true,
      include = [],
      includeParentQueries = [],
      includeQueries = [],
      ignoreNonExisting = true,
      onClickInside,
      onClickOutside,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const refs = {
    root: React.useRef(undefined),
    include: React.useRef(undefined),
    includeQueries: React.useRef(undefined),
    includeParentQueries: React.useRef(undefined),
    ignoreNonExisting: React.useRef(undefined)
  };
  refs.include.current = include;
  refs.includeQueries.current = includeQueries;
  refs.includeParentQueries.current = includeParentQueries;
  refs.ignoreNonExisting.current = ignoreNonExisting;
  React.useEffect(() => {
    const rootDocument = isEnvironment('browser') ? refs.root.current?.ownerDocument || window.document : undefined;
    const onMethod = event => {
      if (refs.root.current) {
        const elementParents = element(event.target).parents();
        const exists = Try(() => rootDocument.body.contains(event.target));
        if (refs.root.current.contains(event.target) || refs.include.current.map(item => item?.current || item).filter(Boolean).some(item => item.contains?.(event.target)) || refs.includeParentQueries.current.some(query => elementParents.some(item => matches(item)(query))) || refs.includeQueries.current.some(query => matches(event.target)(query)) || !exists && refs.ignoreNonExisting.current) {
          if (is('function', onClickInside)) onClickInside();
        } else {
          if (is('function', onClickOutside)) onClickOutside();
        }
      }
    };
    if (mouseEvent) rootDocument.addEventListener(resolve(mouseEvent), onMethod);
    if (touchEvent) rootDocument.addEventListener(resolve(touchEvent), onMethod, {
      passive: true
    });
    if (contextMenu) rootDocument.addEventListener('contextmenu', onMethod);
    return () => {
      if (mouseEvent) rootDocument.removeEventListener(resolve(mouseEvent), onMethod);
      if (touchEvent) rootDocument.removeEventListener(resolve(mouseEvent), onMethod);
      if (contextMenu) rootDocument.removeEventListener('contextmenu', onMethod);
    };
  }, [mouseEvent, touchEvent, contextMenu]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, children && (/*#__PURE__*/React.cloneElement(children, _objectSpread(_objectSpread({
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      if (children.ref) {
        if (is('function', children.ref)) children.ref(item);else children.ref.current = item;
      }
      refs.root.current = item;
    }
  }, other), {}, {
    className: classNames([other.className, children.props.className])
  }))));
});
ClickListener.displayName = 'onesy-ClickListener';
export default ClickListener;

==> ui-react-1.1.440.tgz: package/esm/ClickListener/ClickListener.js <==
import _objectWithoutProperties from "@babel/runtime/helpers/objectWithoutProperties";
import _defineProperty from "@babel/runtime/helpers/defineProperty";
const _excluded = ["mouseEvent", "touchEvent", "contextMenu", "include", "includeParentQueries", "includeQueries", "ignoreNonExisting", "onClickInside", "onClickOutside", "children"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
import React from 'react';
import { is, element, Try, isEnvironment } from '@amaui/utils';
import { classNames, useAmauiTheme } from '@amaui/style-react';
import { matches } from '../utils';
const resolve = value => value.replace(/^on/, '').toLowerCase();
const ClickListener = /*#__PURE__*/React.forwardRef((props_, ref) => {
  const theme = useAmauiTheme();
  const props = React.useMemo(() => _objectSpread(_objectSpread(_objectSpread({}, theme?.ui?.elements?.all?.props?.default), theme?.ui?.elements?.amauiClickListener?.props?.default), props_), [props_]);
  const {
      mouseEvent = 'onClick',
      touchEvent = 'onTouchEnd',
      contextMenu = true,
      include = [],
      includeParentQueries = [],
      includeQueries = [],
      ignoreNonExisting = true,
      onClickInside,
      onClickOutside,
      children
    } = props,
    other = _objectWithoutProperties(props, _excluded);
  const refs = {
    root: React.useRef(),
    include: React.useRef(),
    includeQueries: React.useRef(),
    includeParentQueries: React.useRef(),
    ignoreNonExisting: React.useRef()
  };
  refs.include.current = include;
  refs.includeQueries.current = includeQueries;
  refs.includeParentQueries.current = includeParentQueries;
  refs.ignoreNonExisting.current = ignoreNonExisting;
  React.useEffect(() => {
    const rootDocument = isEnvironment('browser') ? refs.root.current?.ownerDocument || window.document : undefined;
    const onMethod = event => {
      if (refs.root.current) {
        const elementParents = element(event.target).parents();
        const exists = Try(() => rootDocument.body.contains(event.target));
        if (refs.root.current.contains(event.target) || refs.include.current.map(item => item?.current || item).filter(Boolean).some(item => item.contains?.(event.target)) || refs.includeParentQueries.current.some(query => elementParents.some(item => matches(item)(query))) || refs.includeQueries.current.some(query => matches(event.target)(query)) || !exists && refs.ignoreNonExisting.current) {
          if (is('function', onClickInside)) onClickInside();
        } else {
          if (is('function', onClickOutside)) onClickOutside();
        }
      }
    };
    if (mouseEvent) rootDocument.addEventListener(resolve(mouseEvent), onMethod);
    if (touchEvent) rootDocument.addEventListener(resolve(touchEvent), onMethod, {
      passive: true
    });
    if (contextMenu) rootDocument.addEventListener('contextmenu', onMethod);
    return () => {
      if (mouseEvent) rootDocument.removeEventListener(resolve(mouseEvent), onMethod);
      if (touchEvent) rootDocument.removeEventListener(resolve(mouseEvent), onMethod);
      if (contextMenu) rootDocument.removeEventListener('contextmenu', onMethod);
    };
  }, [mouseEvent, touchEvent, contextMenu]);
  return /*#__PURE__*/React.createElement(React.Fragment, null, children && /*#__PURE__*/React.cloneElement(children, _objectSpread(_objectSpread({
    ref: item => {
      if (ref) {
        if (is('function', ref)) ref(item);else ref.current = item;
      }
      if (children.ref) {
        if (is('function', children.ref)) children.ref(item);else children.ref.current = item;
      }
      refs.root.current = item;
    }
  }, other), {}, {
    className: classNames([other.className, children.props.className])
  })));
});
ClickListener.displayName = 'amaui-ClickListener';
export default ClickListener;
